==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/VulnerabilityAssessmentRecurringScansPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a Vulnerability Assessment recurring scans.
 * @property emailSubscriptionAdmins Specifies that the schedule scan notification will be is sent to the subscription administrators.
 * @property emails Specifies an array of e-mail addresses to which the scan notification is sent.
 * @property isEnabled Recurring scans state.
 */
public data class VulnerabilityAssessmentRecurringScansPropertiesArgs(
    public val emailSubscriptionAdmins: Output<Boolean>? = null,
    public val emails: Output<List<String>>? = null,
    public val isEnabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.sql.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.sql.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs =
        com.pulumi.azurenative.sql.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs.builder()
            .emailSubscriptionAdmins(emailSubscriptionAdmins?.applyValue({ args0 -> args0 }))
            .emails(emails?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .isEnabled(isEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VulnerabilityAssessmentRecurringScansPropertiesArgs].
 */
@PulumiTagMarker
public class VulnerabilityAssessmentRecurringScansPropertiesArgsBuilder internal constructor() {
    private var emailSubscriptionAdmins: Output<Boolean>? = null

    private var emails: Output<List<String>>? = null

    private var isEnabled: Output<Boolean>? = null

    /**
     * @param value Specifies that the schedule scan notification will be is sent to the subscription administrators.
     */
    @JvmName("cbmmgqllenotubgi")
    public suspend fun emailSubscriptionAdmins(`value`: Output<Boolean>) {
        this.emailSubscriptionAdmins = value
    }

    /**
     * @param value Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("bobhyrimakjfvaii")
    public suspend fun emails(`value`: Output<List<String>>) {
        this.emails = value
    }

    @JvmName("wwekrnafyxgeuhyg")
    public suspend fun emails(vararg values: Output<String>) {
        this.emails = Output.all(values.asList())
    }

    /**
     * @param values Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("rualmgtuoiybritl")
    public suspend fun emails(values: List<Output<String>>) {
        this.emails = Output.all(values)
    }

    /**
     * @param value Recurring scans state.
     */
    @JvmName("ccgjhotkveidarrw")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Specifies that the schedule scan notification will be is sent to the subscription administrators.
     */
    @JvmName("tohrisdcwocmyxlp")
    public suspend fun emailSubscriptionAdmins(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emailSubscriptionAdmins = mapped
    }

    /**
     * @param value Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("eyrpglhhbhhtdpoy")
    public suspend fun emails(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emails = mapped
    }

    /**
     * @param values Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("deaumbijocwbqmqs")
    public suspend fun emails(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.emails = mapped
    }

    /**
     * @param value Recurring scans state.
     */
    @JvmName("remgpiaoyvsjimgm")
    public suspend fun isEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    internal fun build(): VulnerabilityAssessmentRecurringScansPropertiesArgs =
        VulnerabilityAssessmentRecurringScansPropertiesArgs(
            emailSubscriptionAdmins = emailSubscriptionAdmins,
            emails = emails,
            isEnabled = isEnabled,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/VulnerabilityAssessmentRecurringScansPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a Vulnerability Assessment recurring scans.
 * @property emailSubscriptionAdmins Specifies that the schedule scan notification will be is sent to the subscription administrators.
 * @property emails Specifies an array of e-mail addresses to which the scan notification is sent.
 * @property isEnabled Recurring scans state.
 */
public data class VulnerabilityAssessmentRecurringScansPropertiesArgs(
    public val emailSubscriptionAdmins: Output<Boolean>? = null,
    public val emails: Output<List<String>>? = null,
    public val isEnabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.sql.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.sql.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs =
        com.pulumi.azurenative.sql.inputs.VulnerabilityAssessmentRecurringScansPropertiesArgs.builder()
            .emailSubscriptionAdmins(emailSubscriptionAdmins?.applyValue({ args0 -> args0 }))
            .emails(emails?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .isEnabled(isEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VulnerabilityAssessmentRecurringScansPropertiesArgs].
 */
@PulumiTagMarker
public class VulnerabilityAssessmentRecurringScansPropertiesArgsBuilder internal constructor() {
    private var emailSubscriptionAdmins: Output<Boolean>? = null

    private var emails: Output<List<String>>? = null

    private var isEnabled: Output<Boolean>? = null

    /**
     * @param value Specifies that the schedule scan notification will be is sent to the subscription administrators.
     */
    @JvmName("npjuesvjvhcvtpis")
    public suspend fun emailSubscriptionAdmins(`value`: Output<Boolean>) {
        this.emailSubscriptionAdmins = value
    }

    /**
     * @param value Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("rsvcgpjbcvpsnstg")
    public suspend fun emails(`value`: Output<List<String>>) {
        this.emails = value
    }

    @JvmName("ecfcgggoyhrawgew")
    public suspend fun emails(vararg values: Output<String>) {
        this.emails = Output.all(values.asList())
    }

    /**
     * @param values Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("gdcninsngioqeobb")
    public suspend fun emails(values: List<Output<String>>) {
        this.emails = Output.all(values)
    }

    /**
     * @param value Recurring scans state.
     */
    @JvmName("cvmycsmfkcxonykn")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Specifies that the schedule scan notification will be is sent to the subscription administrators.
     */
    @JvmName("kbpjqupsduijgjwx")
    public suspend fun emailSubscriptionAdmins(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emailSubscriptionAdmins = mapped
    }

    /**
     * @param value Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("eqoupccnoyxpkfjx")
    public suspend fun emails(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emails = mapped
    }

    /**
     * @param values Specifies an array of e-mail addresses to which the scan notification is sent.
     */
    @JvmName("avyorvngowhchjux")
    public suspend fun emails(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.emails = mapped
    }

    /**
     * @param value Recurring scans state.
     */
    @JvmName("fqbmgywatpohsces")
    public suspend fun isEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    internal fun build(): VulnerabilityAssessmentRecurringScansPropertiesArgs =
        VulnerabilityAssessmentRecurringScansPropertiesArgs(
            emailSubscriptionAdmins = emailSubscriptionAdmins,
            emails = emails,
            isEnabled = isEnabled,
        )
}
